# Tangent spaces

Let $\mathrm{M}$ be a differential manifold with $\dim \mathrm{M} = n \in \mathbb{N}$ used throughout the section.

## Definition

> *Definition 1*: let $f \in C^{\infty}(\mathrm{M})$ with $C^{\infty}$ the class of [smooth functions]() and $M$ a differential manifold. A derivation of $f$ at $x \in \mathrm{M}$ is defined as a linear map $\mathbf{v}_x: C^\infty(\mathrm{M}) \to \mathbb{K}$ that satisfies
>
> $$
>   \forall f,g \in C^{\infty}(\mathrm{M}): \mathbf{v}_x(f g) = (\mathbf{v}_xf) g + f (\mathbf{v}_x g).
> $$
>
> Let $\mathrm{T}_x\mathrm{M}$ be the set of all derivations at $x$ such that $\mathbf{v}_x \in \mathrm{T}_x\mathrm{M}$. With $\mathrm{T}_x\mathrm{M}$ denoted as the **tangent space** at $x$. 

We may think of the tangent space at a point $x \in \mathrm{M}$ as a space attached to $x$ on the differential manifold $M$. 

## Properties of tangent spaces

> *Theorem 1*: let $M$ be a differential manifold and let $x \in \mathrm{M}$, the tangent space $\mathrm{T}_x\mathrm{M}$ is a vector space. 

??? note "*Proof*:"

    Will be added later.

Thus, the tangent space is a vector space attached to $x \in \mathrm{M}$ on the differential manifold. It follows that its vectors have interesting properties. 

> *Theorem 2*: let $M$ be a differential manifold, let $x \in \mathrm{M}$ and let $\mathbf{v}_x \in \mathrm{T}_x\mathrm{M}$, then we have that
>
> $$
>   \forall f \in C^{\infty}(\mathrm{M}): \mathbf{v}_x f = v^i \partial_i f(x),
> $$
>
> such that $\mathbf{v}_x = v^i \partial_i \in \mathrm{T}_x\mathrm{M}$ is denoted as a **tangent vector** in the tangent space $\mathrm{T}_x\mathrm{M}$. 


??? note "*Proof*:"

    Will be added later.

Theorem 2 adds the notion of tangent vectors to the explanation of the tangent space. The tangent space at a point on the manifold thus represents the space of tangent vectors.

> *Proposition 1*: let $M$ be a differential manifold of $\dim\mathrm{M} = n \in \mathbb{N}$. The tangent space $\mathrm{T}_x\mathrm{M}$ has dimension $n$ such that
> 
> $$
>   \forall x \in \mathrm{M}: \dim \mathrm{T}_x\mathrm{M} = \dim\mathrm{M}
> $$
> 
> and is span by the vector basis $\{\partial_i\}_{i=1}^n$. 

??? note "*Proof*:"

    Will be added later.

Proposition 1 states that the tangent space is of the same dimension as the manifold and its basis are partial derivative operators. In the context of the [covariant basis](), this definition of the basis leaves out the coordinate map, but is in fact equivalent to the covariant basis.

As a last step in the explanation, we may think of the 2 dimensional surface of a sphere, which may define a differential manifold $M$. The tangent space at a point $x \in \mathrm{M}$ on the surface of the sphere may then be compared to the tangent plane to the sphere attached at point $x \in \mathrm{M}$. The catch is that the 3 dimensional space necessary to understand this construction exists only in our imagination and not in the mathematical construct.

## Tangent bundle

> *Definition 2*: let $M$ be a differential manifold, the collection of tangent spaces $\mathrm{T}_x\mathrm{M}$ for all $x \in \mathrm{M}$ define the **tangent bundle** as 
>
> $$
>   \mathrm{TM} = \bigcup_{x \in \mathrm{M}} \mathrm{T}_x\mathrm{M}.
> $$

In particular, we may think of the tangent bundle $\mathrm{TM}$ as a subspace $\mathrm{TM} \subset V$ of the fiber bundle $V$ for a differential manifold. With the special properties given in theorem 2 and proposition 1. 

The connection of each tangent vector to its base point may be formalised with the projection map $\pi$ which in this case is given by

$$
    \pi: \mathrm{TM} \to\mathrm{M}: (x, \mathbf{v}) \mapsto \pi(x, \mathbf{v}) \overset{\text{def}}{=} x,
$$

and its inverse

$$
    \pi^{-1}:\mathrm{M} \to \mathrm{TM}: x \mapsto \pi^{-1}(x) \overset{\text{def}}{=} \mathrm{T}_x\mathrm{M}.
$$

> *Definition 3*: a vector field $\mathbf{v}$ on a differential manifold $M$ is a section
>
> $$
>   \mathbf{v} \in \Gamma(\mathrm{TM}),
> $$
>
> of the tangent bundle $\mathrm{TM}$. 

## Cotangent spaces

> *Definition 4*: let $M$ be a differential manifold and $\mathrm{T}_x\mathrm{M}$ the tangent space at $x \in \mathrm{M}$. We define the **cotangent space** $\mathrm{T}_x^*\mathrm{M}$ as the dual space of $\mathrm{T}_x\mathrm{M}$
>
> $$
>   \mathrm{T}_x^*\mathrm{M} = (\mathrm{T}_x\mathrm{M})^*.
> $$
> 
> Then every element $\bm{\omega}_x \in \mathrm{T}_x^*\mathrm{M}$ is a linear map $\bm{\omega}_x: \mathrm{T}_x\mathrm{M} \to \mathbb{K}$ denoted as the **cotangent vector**. 

This definition is a logical consequence of the notion of the [dual vector space](). It then also follows that the dual cotangent space is isomorphic to the tangent space at a point $x \in \mathrm{M}$. 

> *Theorem 3*: let $\mathrm{M}$ be a differential manifold of $\dim \mathrm{M} = n \in \mathbb{N}$, then we have that for every $x \in \mathrm{M}$ the basis $\{dx^i\}_{i=1}^n$ of $\mathrm{T}_x^*\mathrm{M}$ is uniquely determined by
>
> $$
>   dx^i(\partial_j) = \delta^i_j,
> $$
>
> for each basis $\{\partial_j\}_{j=1}^n$ in $\mathrm{T}_x\mathrm{M}$. 

??? note "*Proof*:"

    The proof follows directly from theorem 1 in [dual vector spaces](). 

The choice of $dx^i$ can be explained by taking the differential $df = \partial_i f dx^i \in \mathrm{T}_x^*\mathrm{M}$ with $f \in C^\infty(\mathrm{M})$. Then if we take

$$
    \mathbf{k}_x(df, \mathbf{v}) = \mathbf{k}(\partial_i f dx^i, v^j \partial_j) = v^j \partial_i f \mathbf{k}(dx^i, \partial_j) = v^j \partial_i f \delta^i_j = v^i \partial_i f = \mathbf{v} f,
$$

with $\mathbf{k}_x: \mathrm{T}_x^*\mathrm{M} \times \mathrm{T}_x\mathrm{M} \to \mathbb{K}$ the Kronecker tensor at $x \in \mathrm{M}$. Which shows that defining the basis of the cotangent space as differentials corresponds with respect to the basis of the tangent space.

So, a cotangent vector $\bm{\omega}_x \in \mathrm{T}_x^*\mathrm{M}$ may be decomposed into

$$
    \bm{\omega}_x = \omega_i dx^i. 
$$

In the context of the [contravariant basis](), this definition of the basis leaves out the coordinate map, but is in fact equivalent to the contravariant basis.

## Cotangent bundle

> *Definition 5*: let $M$ be a differential manifold, the collection of cotangent spaces $\mathrm{T}_x^*\mathrm{M}$ for all $x \in \mathrm{M}$ define the **cotangent bundle** as 
>
> $$
>   \mathrm{T^*M} = \bigcup_{x \in \mathrm{M}} \mathrm{T}_x^*\mathrm{M}.
> $$

Thus, we may think of the cotangent bundle $\mathrm{T^*M}$ as a subspace $\mathrm{T^*M} \subset V^*$ of the dual fiber bundle $V^*$ for a differential manifold.