# Inner product spaces

> *Definition 1*: a vector space $X$ over a field $F$ is an **inner product space** if an **inner product** $\langle \cdot, \cdot \rangle: X \times X \to F$ is defined on $X$ satisfying
>
> 1. $\forall x \in X: \langle x, x \rangle \geq 0$,
> 2. $\langle x, x \rangle = 0 \iff x = 0$,
> 3. $\forall x, y \in X: \langle x, y \rangle = \overline{\langle y, x \rangle}$,
> 4. $\forall x, y \in X, \alpha \in F: \langle \alpha x, y \rangle = \alpha \langle x, y \rangle$,
> 5. $\forall x, y, z \in X: \langle x + y, z \rangle = \langle x, z \rangle + \langle y, z \rangle$.

Similar to the case in normed spaces we have the following proposition.

> *Proposition 1*: an inner product $\langle \cdot, \cdot \rangle$ on a vector space $X$ defines a norm $\|\cdot\|$ on $X$ given by
>
> $$
>   \|x\| = \sqrt{\langle x, x \rangle},
> $$
>
> for all $x \in X$ and is called the **norm induced by the inner product**.

??? note "*Proof*:"

    Will be added later.

Which makes an inner product space also a normed space as well as a metric space, referring to proposition 1 in normed spaces.

> *Definition 2*: a **Hilbert space** $H$ is a complete inner product space with its metric induced by the inner product.

Definition 2 makes a Hilbert space also a Banach space, using proposition 1.

## Properties of inner product spaces

> *Proposition 2*: let $(X, \langle \cdot, \cdot \rangle)$ be an inner product space, then
>
> $$
>   \| x + y \|^2 + \| x - y \|^2 = 2\big(\|x\|^2 + \|y\|^2\big), 
> $$
>
> for all $x, y \in X$.

??? note "*Proof*:"

    Will be added later.

Proposition 2 is also called the parallelogram identity.

> *Lemma 1*: let $(X, \langle \cdot, \cdot \rangle)$ be an inner product space, then
>
> 1. $\forall x, y \in X: |\langle x, y \rangle| \leq \|x\| \cdot \|y\|$,
> 2. $\forall x, y \in X: \|x + y\| \leq \|x\| + \|y\|$.

??? note "*Proof*:"

    Will be added later.

Statement 1 in lemma 1 is known as the Schwarz inequality and statement 2 is known as the triangle inequality and will be used throughout the section of inner product spaces.

> *Lemma 2*: let $(X, \langle \cdot, \cdot \rangle)$ be an inner product space and let $(x_n)_{n \in \mathbb{N}}$ and $(y_n)_{n \in \mathbb{N}}$ be sequences in $X$, if we have  $x_n \to x$ and $y_n \to y$ as $n \to \infty$, then
>
> $$
>   \lim_{n \to \infty} \langle x_n, y_n \rangle = \langle x, y \rangle.
> $$

??? note "*Proof*:"

    Will be added later.

## Completion

> *Definition 3*: an **isomorphism** $T$ of an inner product space $(X, \langle \cdot, \cdot \rangle)_X$ onto an inner product space $(\tilde X, \langle \cdot, \cdot \rangle)_{\tilde X}$ over the same field $F$ is a bijective linear operator $T: X \to \tilde X$ which preserves the inner product
>
> $$
>   \langle Tx, Ty \rangle_{\tilde X} = \langle x, y \rangle_X,
> $$
>
> for all $x, y \in X$. 

As a first application of lemma 2, let us prove the following.

> *Theorem 1*: for every inner product space $(X, \langle \cdot, \cdot \rangle)_X$ there exists a Hilbert space $(\tilde X, \langle \cdot, \cdot \rangle)_{\tilde X}$ that contains a subspace $W$ that satisfies the following conditions
>
> 1. $W$ is an inner product space isomorphic with $X$. 
> 2. $W$ is dense in $X$. 

??? note "*Proof*:"

    Will be added later.

Somewhat trivially, we have that a subspace $M$ of an inner product space $X$ is defined to be a vector subspace of $X$ taken with the inner product on $X$ restricted to $M \times M$. 

> *Proposition 3*: let $Y$ be a subspace of a Hilbert space $X$, then
>
> 1. $Y$ is complete $\iff$ $Y$ is closed in $X$,
> 2. if $Y$ is finite-dimensional, then $Y$ is complete,
> 3. $Y$ is separable if $X$ is separable.

??? note "*Proof*:"

    Will be added later.

## Orthogonality

> *Definition 4*: let $(X, \langle \cdot, \cdot \rangle)$ be an inner product space, a vector $x \in X$ is **orthogonal** to a vector $y \in X$ if
>
> $$
>   \langle x, y \rangle = 0,
> $$
>
> and we write $x \perp y$. 

Furthermore, we can also say that $x$ and $y$ *are orthogonal*. 

> *Definition 5*: let $(X, \langle \cdot, \cdot \rangle)$ be an inner product space and let $A, B \subset X$ be subspaces of $X$. Then $A$ is **orthogonal** to $B$ if for every $x \in A$ and $y \in B$ we have
>
> $$
>   \langle x, y \rangle = 0,
> $$
>
> and we write $A \perp B$.

Similarly, we may state that $A$ and $B$ *are orthogonal*.

