# Topological notions

> *Definition 1*: let $(X,d)$ be a metric space and let $x_0 \in X$ and $r > 0$, the following may be defined 
>
> 1. **open ball**: $B(x_0, r) = \{x \in X \;|\; d(x,x_0) < r\}$,
> 2. **closed ball**: $\tilde B(x_0,r) = \{x \in X \;|\; d(x,x_0) \leq r\}$,
> 3. **sphere**: $S(x_0,r) = \{x \in X \;|\; d(x,x_0) = r\}$. 

In all three cases $x_0$ can be thought of as the center and $r$ as the radius.

> *Definition 2*: a subset $M \subset X$ of a metric space $(X,d)$ is **open** if $\forall x_0 \in M \exists r > 0: B(x_0,r) \subset M$. 
> 
> $M$ is **closed** if $X \backslash M$ is open. 

Therefore, one may observe that an open ball is an open set and a closed ball is a closed set.

## Neigbourhoods

> *Definition 3*: let $(X,d)$ be a metric space and let $x_0 \in X$, then $B(x_0, \varepsilon)$ is an **$\varepsilon$-neighbourhood** of $x_0$ for some $\varepsilon > 0$. 

Using definition 3 we may define the following.

> *Definition 4*: a **neighbourhood** of $x_0$ is a set that contains an $\varepsilon$-neighbourhood of $x_0$ for some $\varepsilon > 0$. 

Therefore $x_0$ is an element of each of its neighbourhoods and if $N$ is a neighbourhood of $x_0$ and $N \subset M$, then $M$ is also a neighbourhood of $x_0$. 

> *Definition 5*: let $(X,d)$ be a metric space and let $M \subset X$, a point $x_0 \in M$ is an **interior point** of $M$ if $M$ is a neighbourhood of $x_0$. 

One may think of an interior point of a subset as a point that lies within the interior of $M$.

> *Definition 6*: let $(X,d)$ be a metric space and let $M \subset X$, the **interior** of $M$, denoted by $M^\circ$ is the set of all interior points of $M$. 

One may observe that $M^\circ$ is open and is the largest open set contained in $M$.

> *Lemma 1*: let $(X,d)$ be a metric space and let $\mathscr{T}$ be the set of all open subsets of $X$, then
>
> 1. $\empty \in \mathscr{T} \land X \in \mathscr{T}$, 
> 2. the union of a collection of sets in $\mathscr{T}$ is itself a set in $\mathscr{T}$,
> 3. the intersection of a finite collection of sets in $\mathscr{T}$ is a set in $\mathscr{T}$. 

??? note "*Proof*:"

    Statement 1 follows by noting that $\empty$ is open since $\empty$ has no elements and $X$ is open. 

    For statement 2 we have that for any point $x$ of the union $U$ of open sets belongs to at least one of these sets $M$ and $M$ contains a ball $B$ about $x$. Then $B \subset U$, by the definition of a union. 

    For statement 3 we have that if $y$ is any point of the intersection of open sets $M_1, \dots, M_n$ with $n \in \mathbb{N}$ then each $M_j$ contains a ball about $y$ and the smallest of these balls is contained in that intersection. 

From statements 1 and 3 from *lemma 1* we may define a topological space $(X,\mathscr{T})$ to be a set $X$ and a collection $\mathscr{T}$ of subsets of $X$ such that $\mathscr{T}$ satisfies the axioms 1 and 3. The set $\mathscr{T}$ is a topology for $X$, and it follows that a metric space is a topological space.

## Continuity

> *Definition 7*: let $(X,d)$ and $(Y,\tilde d)$ be metric spaces and let $T: X \to Y$ be a map. $T$ is **continuous in** $x_0 \in X$ if 
>
> $$
>   \forall \varepsilon > 0 \exists \delta > 0 \forall x \in X: \quad d(x,x_0) < \delta \implies \tilde d \big(T(x), T(x_0) \big) < \varepsilon.
> $$
>
> A mapping $T$ is **continuous** if it is continuous in all $x_0 \in X$. 

Continuous mappings can be characterized in terms of open sets as follows.

> *Theorem 1*: let $(X,d)$ and $(Y,\tilde d)$ be metric spaces, a mapping $T: X \to Y$ is continuous if and only if the inverse image of any open subset of $Y$ is an open subset of $X$.

??? note "*Proof*:"

    Suppose that $T$ is continuous. Let $S \subset Y$ be open and $S_0$ the inverse image of $S$. If $S_0 = \empty$, it is open. Let $S_0 = \empty$. For any $x \in S_0$ let $y_0 = T(x_0)$. Since $S$ is open, it contains an $\varepsilon$-neighbourhood $N$ of $y_0$. Since $T$ is continuous, $x_0$ has a $\delta$-neighbourhood $N_0$ which is mapped into $N$. Since, $N \subset S$ we have $N_0 \subset S_0$ so that $S_0$ is open because $x_0 \in S_0$ is arbitrary.

    Suppose that the inverse image of every open set in $Y$ is an open set in $X$. Then for every $x_0 \in X$ and any $\varepsilon$-neighbourhood $N$ of $T(x_0)$, the inverse image $N_0$ of $N$ is open, since $N$ is open, and $N_0$ contains $x_0$. Hence, $N_0$ also contains a $\delta$-neighbourhood of $x_0$, which is mapped into $N$ because $N_0$ is mapped into $N$. Consequently, $T$ is continuous at $x_0$. Since $x_0 \in X$ was chosen arbitrary, $T$ is continuous.

## Accumulation points

> *Definition 8*: let $M \subset X$ be a subset of a metric space $(X,d)$. A point $x_0 \in X$ is an **accumulation point** of $M$ if 
> 
> $$
> \forall \varepsilon > 0 \exists y \in M \backslash \{x_0\}: d(x_0,y) < \varepsilon.
> $$ 

An accumulation point of a subset $M$ is also sometimes called a limit point of $M$. Implying the nature of these points. 

> *Definition 9*: the set consisting of all points of $M$ and all accumulation points of $M$ is the **closure** of $M$, denoted by $\overline M$. 

Therefore, $\overline M$ is the smallest closed set containing $M$. 

> *Definition 10*: let $(X,d)$ be a metric space and let $M$ be a subset of $X$. The set $M$ is dense in $X$ if $\overline M = X$. 

Hence if $M$ is dense in $X$, then every ball in $X$, no matter how small, will contain points of $M$. 

> *Definition 11*: a metric space $(X,d)$ is separable if $X$ contains a countable subset $M$ that is dense in $X$. 

For example the real line $\mathbb{R}$ is separable, since the set $\mathbb{Q}$ of all rational numbers is countable and is dense in $\mathbb{R}$. 

Furthermore, $l^\infty$ is not separable while $l^p$ is indeed separable.

??? note "*Proof*:"

    Will be added later.