# Vector spaces

> *Definition 1*: a **vector space** $X$ over a **scalar field** $F$ is a non-empty set, on which two algebraic operations are defined; vector addition and scalar multiplication. Such that
>
> 1. $(X, +)$ is a commutative group with neutral element 0.
> 2. the scalar multiplication satisfies $\forall x, y \in X$ and $\lambda, \mu \in F$ 
>    * $\lambda (x + y) = \lambda x + \lambda y$,
>    * $(\lambda + \mu) x = \lambda x + \mu x$,
>    * $\lambda (\mu x) = (\lambda \mu) x$,
>    * $1 x = x$.

When $F = \mathbb{R}$ we have a real vector space while when $F = \mathbb{C}$ we have a complex vector space.

We have that the metric spaces $\mathbb{R}^n$, $C$, $l^p$ and $l^\infty$ are also vector spaces.

??? note "*Proof*:"

    I am too lazy to add this trivial proof. Maybe some time in the future, if I do not forget.

> *Definition 2*: a **subspace** of a vector space $X$ is a non-empty subset $M$ of $X$, such that $\forall x, y \in M$ and $\lambda, \mu \in F$: 
>
> $$
>   \lambda x + \mu y \in M,
> $$
>
> with $M$ itself a vector space.

A special subspace $M$ of a vector space $X$ is the *improper subspace* $M = X$. Every other subspace of $X$ is a *proper subspace*.

## Linear combinations

> *Definition 3*: a **linear combination** of the vectors $\{x_i\}_{i=1}^n$ with $n \in \mathbb{N}$ is vector of the form
>
> $$
>   \alpha_1 x_1 + \dots + \alpha_n x_n = \sum_{i=1}^n \alpha_i x_i,
> $$
>
> with $\{\alpha_i\}_{i=1}^n \in F$. 

The set of all linear combinations of a set of vectors is defined as follows.

> *Definition 4*: the **span** of a subset $M \subset X$ of a vector space $X$, denoted by $\mathrm{span}(M)$, is the set of all linear combinations of vectors from $M$.

It follows that $\mathrm{span}(M)$ is a subspace of $X$.

## Linear independence

> *Definition 5*: a finite subset of vectors $M = \{x_i\}_{i=1}^n$ is **linearly independent** if 
>
> $$
>   \sum_{i=1}^n \alpha_i x_i = 0 \implies \forall i \in \{1, \dots, n\}: \alpha_i = 0.
> $$

The converse may also be defined.

> *Definition 6*: a finite subset of vectors $M = \{x_i\}_{i=1}^n$ is **linearly dependent** if $\exists \{\alpha_i\}_{i=1}^n \in F$ not all zero such that
>
> $$
>   \sum_{i=1}^n \alpha_i x_i = 0.
> $$

The notions of linear dependence and independence may also be extended to infinite subsets.

> *Definition 7*: a subset $M$ of a vector space $X$ is **linearly independent** if every non-empty finite subset of $M$ is linearly independent.

While the converse in this case is defined by the contradiction.

> *Definition 8*: a subset $M$ of a vector space $X$ is **linearly dependent** if $M$ is not linearly independent. 

## Dimension and basis

> *Definition 9*: a vector space $X$ is **finite dimensional** if there exists a $n \in \mathbb{N}$, such that $X$ contains a set of $n$ linearly independent vectors, while every set of $n+1$ vectors in $X$ is linearly dependent. In this case $n$ is the dimension of $X$, denoted by $\dim X = n$.

By definition $X = \{0\}$ is finite dimensional and $\dim X = 0$. 

> *Definition 10*: if a vector space $X$ is not finite dimensional then $X$ is **infinite dimensional**.

The following definition of a basis is both relevant to finite and infinite dimensional vector spaces.

> *Definition 11*: a **basis** $B$ of a vector space $X$ is a linearly independent subset of $X$, that spans $X$.

Such a set $B$ is also called a *Hamel basis* of $X$.

> *Theorem 1*: every vector space $X$ has a Hamel basis.

??? note "*Proof*:"

    Read it again, a proof is not necessary.

> *Theorem 2*: let $X$ be a vector space with $\dim X = n \in \mathbb{N}$. Then any proper subspace $M \subset X$ has dimension less than $n$. 

??? note "*Proof*:"

    If $n = 0$, then $X = \{0\}$ and $X$ has no proper subspace.

    If $\dim M = 0$, then $M = \{0\}$ and $X \neq M \implies \dim X \geq 1$. 

    If $\dim M = n$ then $M$ would have a basis of $n$ elements, which would also be a basis for $X$ since $\dim X = n$, so that $X = M$. 

    This shows that any linearly independent set of vectors in $M$ must have fewer than $n$ elements and $\dim M < n$. 