# Tensor symmetries

We have a $n \in \mathbb{N}$ finite dimensional vector space $V$ such that $\dim V = n$, with a basis $\{\mathbf{e}_i\}_{i=1}^n,$ a corresponding dual space $V^*$ with a basis $\{\mathbf{\hat e}^i\}$ and a pseudo inner product $\bm{g}$ on $V.$

## Symmetric tensors

> *Definition 1*: let $\pi = [\pi(1), \dots, \pi(k)]$ be any permutation of the set $\{1, \dots, k\}$, then $\mathbf{T} \in \mathscr{T}^0_q(V)$ is a **symmetric covariant** $q$-tensor if for all $\mathbf{v}_1, \dots, \mathbf{v}_q \in V$ we have
>
> $$
>   \mathbf{T}(\mathbf{v}_{\pi(1)}, \dots, \mathbf{v}_{\pi(q)}) = \mathbf{T}(\mathbf{v}_1, \dots, \mathbf{v}_q),
> $$
>
> with $k = q \in \mathbb{N}$.
> 
> Likewise, $\mathbf{T} \in \mathscr{T}^p_0(V)$ is a **symmetric contravariant** $p$-tensor if for all $\mathbf{\hat u}_1, \dots, \mathbf{\hat u}_p \in V^*$ we have
>
> $$
>   \mathbf{T}(\mathbf{\hat u}_{\pi(1)}, \dots, \mathbf{\hat u}_{\pi(p)}) = \mathbf{T}(\mathbf{\hat u}_1, \dots, \mathbf{\hat u}_p),
> $$
>
> with $k = p \in \mathbb{N}$. 

This symmetry implies that the ordering of the (co)vector arguments in a tensor evaluation do not affect the outcome. 

> *Definition 2*: the vector space of symmetric covariant $q$-tensors is denoted by $\bigvee_q(V) \subset \mathscr{T}^0_q(V)$ and the vector space of symmetric contravariant $p$-tensors is denoted by $\bigvee^p(V) \subset \mathscr{T}^p_0(V).$

Alternatively one may write $\bigvee_q(V) = V^* \otimes_s \cdots \otimes_s V^*$ and $\bigvee^p(V) = V \otimes_s \cdots \otimes_s V.$

## Antisymmetric tensors

> *Definition 3*: let $\pi = [\pi(1), \dots, \pi(k)]$ be any permutation of the set $\{1, \dots, k\}$, then $\mathbf{T} \in \mathscr{T}^0_q(V)$ is an **antisymmetric covariant** $q$-tensor if for all $\mathbf{v}_1, \dots, \mathbf{v}_q \in V$ we have
>
> $$
>   \mathbf{T}(\mathbf{v}_{\pi(1)}, \dots, \mathbf{v}_{\pi(q)}) = \mathrm{sign}(\pi) \mathbf{T}(\mathbf{v}_1, \dots, \mathbf{v}_q),
> $$
>
> with $k = q \in \mathbb{N}$.
>
> Likewise, $\mathbf{T} \in \mathscr{T}^p_0(V)$ is an **antisymmetric contravariant** $p$-tensor if for all $\mathbf{\hat u}_1, \dots, \mathbf{\hat u}_p \in V^*$ we have
>
> $$
>   \mathbf{T}(\mathbf{\hat u}_{\pi(1)}, \dots, \mathbf{\hat u}_{\pi(p)}) = \mathrm{sign}(\pi)\mathbf{T}(\mathbf{\hat u}_1, \dots, \mathbf{\hat u}_p),
> $$
>
> with $k = p \in \mathbb{N}$. 

This antisymmetry implies that the ordering of the (co)vector arguments in a tensor evaluation only change the sign of the outcome. 

> *Definition 4*: the vector space of antisymmetric covariant $q$-tensors is denoted by $\bigwedge_q(V) \subset \mathscr{T}^0_q(V)$ and the vector space of antisymmetric contravariant $p$-tensors is denoted by $\bigwedge^p(V) \subset \mathscr{T}^p_0(V).$

Alternatively one may write $\bigwedge_q(V) = V^* \otimes_a \cdots \otimes_a V^*$ and $\bigwedge^p(V) = V \otimes_a \cdots \otimes_a V.$

It follows from the definitions of symmetric and antisymmetric tensors that for $0$-tensors we have

$$
    {\bigvee}_0(V) = {\bigvee}^0(V) = {\bigwedge}_0(V) = {\bigwedge}^0(V) = \mathbb{K}.
$$

Furthermore, for $1$-tensors we have

$$
    {\bigvee}_1(V) = {\bigwedge}_1(V) = V^*,
$$

and

$$
    {\bigvee}^1(V) = {\bigwedge}^1(V) = V.
$$

## Symmetrisation maps

The following statements are given with the covariant $q$-tensor without loss of generality.

> *Definition 5*: the linear **symmetrisation map** $\mathscr{S}: \mathscr{T}^0_q \to \bigvee_q(V)$ is given by
>
> $$
>   \mathscr{S}(\mathbf{T})(\mathbf{v}_1, \dots, \mathbf{v}_q) = \frac{1}{q!} \sum_\pi \mathbf{T}(\mathbf{v}_{\pi(1)}, \dots, \mathbf{v}_{\pi(q)}), 
> $$
>
> for all $\mathbf{T} \in \mathscr{T}^0_q(V)$ in which summation runs over all permutations $\pi$ of the set $\{1, \dots, q\}$.

Let $\mathbf{T} = T_{i_1 \cdots i_q} \mathbf{\hat e}^{i_1} \otimes \cdots \otimes \mathbf{\hat e}^{i_q} \in \mathscr{T}^0_q(V)$, then we have $\mathscr{S}(\mathbf{T}) = T_{(i_1 \cdots i_q)} \mathbf{\hat e}^{i_1} \otimes \cdots \otimes \mathbf{\hat e}^{i_q} \in \bigvee_q(V)$ with

$$
    T_{(i_1 \cdots i_q)} = \frac{1}{q!} \sum_\pi T_{i_{\pi(1)} \cdots i_{\pi(q)}}. 
$$

If $\mathbf{T} \in \bigvee_q(V)$ then $\mathbf{T} = \mathscr{S}(\mathbf{T})$. The symmetrisation map is idempotent such that $\mathscr{S} \circ \mathscr{S} = \mathscr{S}.$

> *Definition 6*: the linear **antisymmetrisation map** $\mathscr{A}: \mathscr{T}^0_q(V) \to \bigwedge_q(V)$ is given by
>
> $$
>   \mathscr{A}(\mathbf{T})(\mathbf{v}_1, \dots, \mathbf{v}_q) = \frac{1}{q!} \sum_\pi \mathrm{sign}(\pi) \mathbf{T}(\mathbf{v}_{\pi(1)}, \dots, \mathbf{v}_{\pi(q)}), 
> $$
>
> for all $\mathbf{T} \in \mathscr{T}^0_q(V)$ in which summation runs over all permutations $\pi$ of the set $\{1, \dots, q\}$.

Let $\mathbf{T} = T_{i_1 \cdots i_q} \mathbf{\hat e}^{i_1} \otimes \cdots \otimes \mathbf{\hat e}^{i_q} \in \mathscr{T}^0_q(V)$, then we have $\mathscr{A}(\mathbf{T}) = T_{[i_1 \cdots i_q]} \mathbf{\hat e}^{i_1} \otimes \cdots \otimes \mathbf{\hat e}^{i_q} \in \bigwedge_q(V)$ with

$$
    T_{[i_1 \cdots i_q]} = \frac{1}{q!} \sum_\pi \mathrm{sign}(\pi) T_{i_{\pi(1)} \cdots i_{\pi(q)}}.
$$

If $\mathbf{T} \in \bigwedge_q(V)$ then $\mathbf{T} = \mathscr{A}(\mathbf{T})$. The antisymmetrisation map is idempotent such that $\mathscr{A} \circ \mathscr{A} = \mathscr{A}.$

## Symmetric product

The outer product does not preserve (anti)symmetry. For this reason alternative product operators are introduced which preserve (anti)symmetry. The following statements are given with covariant tensors without loss of generality.

> *Definition 7*: the **symmetric product** between two tensors is defined as
>
> $$
>   \mathbf{T} \vee \mathbf{S} = (q+s)! \cdot \mathscr{S}(\mathbf{T} \otimes \mathbf{S}),
> $$
>
> for all $\mathbf{T} \in \mathscr{T}^0_q(V)$ and $\mathbf{S} \in \mathscr{T}^0_s(V)$ with $q,s \in \mathbb{N}$.

It follows from definition 7 that the symmetric product is associative, bilinear and symmetric. Subsequently, we may write a basis of $\bigvee_q(V)$ as

$$
    \mathscr{S}(\mathbf{\hat e}^{i_1} \otimes \cdots \otimes \mathbf{\hat e}^{i_q}) = \frac{1}{q!} \mathbf{\hat e}^{i_1} \vee \cdots \vee \mathbf{\hat e}^{i_q},
$$

with $\{1 \leq i_1 \leq \dots \leq i_q \leq n\}$. 

Let $\mathbf{T} \in \bigvee_q(V)$ and $\mathbf{S} \in \bigvee_s(V)$ then it follows that

$$
    \mathbf{T} \vee \mathbf{S} = \mathbf{S} \vee \mathbf{T}. 
$$

> *Definition 8*: the **antisymmetric product** between two tensors is defined as
>
> $$
>   \mathbf{T} \wedge \mathbf{S} = (q+s)! \cdot \mathscr{A}(\mathbf{T} \otimes \mathbf{S}),
> $$
>
> for all $\mathbf{T} \in \mathscr{T}^0_q(V)$ and $\mathbf{S} \in \mathscr{T}^0_s(V)$ with $q,s \in \mathbb{N}$.

It follows from definition 8 that the antisymmetric product is associative, bilinear and antisymmetric. Subsequently, we may write a basis of $\bigwedge_q(V)$ as

$$
    \mathscr{A}(\mathbf{\hat e}^{i_1} \otimes \cdots \otimes \mathbf{\hat e}^{i_q}) = \frac{1}{q!} \mathbf{\hat e}^{i_1} \wedge \cdots \wedge \mathbf{\hat e}^{i_q},
$$

with $\{1 \leq i_1 < \dots < i_q \leq n\}$. 

Let $\mathbf{T} \in \bigwedge_q(V)$ and $\mathbf{S} \in \bigwedge_s(V)$ then it follows that

$$
    \mathbf{T} \wedge \mathbf{S} = (-1)^{qs} \mathbf{S} \wedge \mathbf{T}. 
$$

> *Theorem 1*: the dimension of the vector space of symmetric covariant $q$-tensors is given by 
> 
> $$
>   \dim \Big({\bigvee}_q(V) \Big) = \binom{n+q-1}{q},
> $$
>
> and for antisymmetric covariant $q$-tensors the dimension is given by
>
> $$
>   \dim \Big({\bigwedge}_q(V) \Big) = \binom{n}{q}.
> $$

??? note "*Proof*:"

    Will be added later.

An interesting result of the definition of the symmetric and antisymmetric product is given in the theorem below.

> *Theorem 2*: let $\mathbf{\hat u}_{1,2} \in V^*$ be covectors, the symmetric product of $\mathbf{\hat u}_1$ and $\mathbf{\hat u}_2$ may be given by
>
> $$
>   (\mathbf{\hat u}_1 \vee \mathbf{\hat u}_2)(\mathbf{v}_1, \mathbf{v}_2) = \mathrm{perm}\big(\mathbf{k}(\mathbf{\hat u}_i, \mathbf{v}_j)\big),
> $$
>
> for all $(\mathbf{v}_1, \mathbf{v}_2) \in V \times V$ with $(i,j)$ denoting the entry of the matrix over which the permanent is taken. 
>
> The antisymmetric product of $\mathbf{\hat u}_1$ and $\mathbf{\hat u}_2$ may be given by
>
> $$
>   (\mathbf{\hat u}_1 \wedge \mathbf{\hat u}_2)(\mathbf{v}_1, \mathbf{v}_2) = \det \big(\mathbf{k}(\mathbf{\hat u}_i, \mathbf{v}_j) \big),
> $$
>
> for all $(\mathbf{v}_1, \mathbf{v}_2) \in V \times V$ with $(i,j)$ denoting the entry of the matrix over which the determinant is taken. 

??? note "*Proof*:"

    Will be added later.

In some literature theorem 2 is used as definition for the symmetric and antisymmetric product from which the relation with the symmetrisation maps can be proven. Either method is valid, however it has been chosen that defining the products in terms of the symmetrisation maps is more general.