# Newtonian formalism of mechanics

## Fundamental assumptions

> *Postulate 1*: there exists an absolute space in which the axioms of Euclidean geometry hold.

The properties of space are constant, immutable and entirely independent of the presence of objects and of all dynamical processes that occur within it.

> *Postulate 2*: there exists an absolute time, entirely independent.

From postulate 1 and 2 we obtain the notion that simultaneity is absolute. In the sense that incidents that occur simultaneously in one reference system, occur simultaneously in all reference systems, independent of their mutual dynamic states or relations.

The definition of a reference system will follow in the next section.

> *Principle of relativity*: all physical axioms are of identical form in all **inertial** reference systems.

It follows from the principle of relativity that the notion of absolute velocity does not exist.

> *Postulate 3*: space and time are continuous, homogeneous and isotropic.

Implying that there is no fundamental limit to the precision of measurements of spatial positions, velocities and time intervals. There are no special locations or instances in time all positions and times are equivalent. The properties of space and time are invariant under translations. And there are no special directions, all directions are equivalent. The properties of space and time are invariant under rotations and reflections.

## Galilean transformations

> *Definition 1*: a **reference system** is an abstract coordinate system whose origin, orientation, and scale are specified by a set of geometric points whose position is identified both mathematically and physically.

From the definition of a reference system and postulates 1, 2 and 3 the Galilean transformations may be posed, which may be used to transform between the coordinates of two reference systems. 

> *Principle 1*: let $(\mathbf{x},t) \in \mathbb{R}^4$ be a general point in spacetime. 
> 
> A uniform motion with velocity $\mathbf{v}$ is given by
>
> $$
>   (\mathbf{x},t) \mapsto (\mathbf{x} + \mathbf{v}t,t),
> $$
>
> for all $\mathbf{v}\in \mathbb{R}^3$.
>
> A translation by $(\mathbf{a},t)$ is given by
>
> $$
>   (\mathbf{x},t) \mapsto (\mathbf{x} + \mathbf{a},t + s),
> $$
>
> for all $(\mathbf{a},t) \in \mathbb{R}^4$. 
>
> A rotation by $R$ is given by
>
> $$
>   (\mathbf{x},t) \mapsto (R \mathbf{x},t),
> $$
>
> for all orthogonal transformations $R: \mathbb{R}^3 \to \mathbb{R}^3$. 

The Galilean transformations may form a Lie group. 

## Axioms of Newton

> *Axiom 1*: in the absence of external forces, a particle moves with a constant speed along a straight line. 
>
> *Axiom 2:* the net force on a particle is equal to the rate at which the particle's momentum changes with time.
>
> *Axiom 3:* if two particles exert forces onto each other, then the mutual forces have equal magnitudes but opposite directions.

From axiom 1 and the principle of relativity the definition of a inertial reference system may be posed. 

> *Definition 2*: an **inertial reference system** is a reference system in which the first axiom of Newton holds.

This implies that a inertial reference system is reference system not undergoing any acceleration. Therefore we may postulate the following. 

> *Postulate 4*: inertial reference systems exist.

<br>

> *Definition 3*: considering two particles $i \in \{1,2\}$ which exert forces onto each other having accelerations $\mathbf{a}_i$. Since by the 2nd and 3rd axiom we have that $\mathbf{a}_1 = - \mathbf{a}_2$ and that the ratio of their magnitudes is a constant we define the ratio of the inertial masses by
>
> $$
>   \frac{m_1}{m_2} = \frac{\|\mathbf{a}_2\|}{\|\mathbf{a}_1\|}. 
> $$

A particle with a mass can be considered as a point mass, which is defined below.

> *Definition 4*: a point mass is defined as a point in space and time appointed with a mass.

## Forces

> *Definition 5*: a force $\mathbf{F}$ is defined as
>
> $$
>   \mathbf{F} = m \mathbf{a},
> $$
>
> with $m \in \mathbb{R}$ the inertial mass and $\mathbf{a}$ the acceleration of the particle.

Definition 5 also implies the equation of motion, for a constant force a second order ordinary differential equation of the position.

> *Proposition 1*: in the case that a force only depends on position, the equation of motion is invariant to time inversion and time translation.

??? note "*Proof*:"

    Will be added later.

This implies that for a moving a particle in a force field it can not be deduced at what point in time it occured and whether it is moving forward or backward in time.

> *Definition 6*: a central force $\mathbf{F}$ representing the interaction between two point masses at positions $\mathbf{x}_1$ and $\mathbf{x}_2$ is defined as 
>
> $$
>   \mathbf{F} = F(\mathbf{x}_1,\mathbf{x}_2) \frac{\mathbf{x}_2 - \mathbf{x}_1}{\|\mathbf{x}_2 - \mathbf{x}_1\|} \overset{\mathrm{def}} = F(\mathbf{x}_1,\mathbf{x}_2) \mathbf{e}_r,
> $$
>
> with $F: (\mathbf{x}_1,\mathbf{x}_2) \mapsto F(\mathbf{x}_1,\mathbf{x}_2)$ the magnitude.

Which for a isotropic central force depends only on the distance between the pointmasses $\|\mathbf{x}_2 - \mathbf{x}_1\|$. 

### Gravitational force of Newton

> *Postulate 5*: the force $\mathbf{F}$ between two particles described by their positions $\mathbf{x}_{1,2}: t \mapsto \mathbf{x}_{1,2}(t)$ is given by
>
> $$
>   \mathbf{F} = G \frac{m_1 m_2}{\|\mathbf{x}_2 - \mathbf{x}_1\|^2} \mathbf{e}_r, 
> $$
>
> with $m_{1,2} \in \mathbb{R}$ the gravitational mass of both particles and $G \in \mathbb{R}$ the gravitational constant. 

According to the observation of Galilei; all object fall with equal speed (in the absence of air friction), which implies that the ratio of inertial and gravitational mass is a constant for any kind of matter.

> *Principle 2*: the inertial and gravitational mass of a particle are equal.

